==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mots/lang/adminmots_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/adminmots?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_associer' => 'Zuordnen',
	'bouton_dissocier' => 'Entfernen',
	'bouton_fusionner' => 'Zusammenführen',

	// E
	'erreur_admin_mot_action_inconnue' => 'Was möchsten Sie tun?',
	'erreur_mot_cle_deja' => 'Nicht möglich: Sie befinden sich bei diesem Schlagwort.',
	'erreur_selection_id' => 'Wählen Sie ein Schlagwort oder geben Sie seine ID im Eingabefeld an.',

	// I
	'icone_administrer_mot' => 'Erweitert',

	// L
	'label_associer_objets_mot' => 'Dieses Wort Objekten erneut <b>zuordnen</b>',
	'label_confirm_fusion' => 'Dieser Vorgang kann nicht rückgängig gemacht werden.<br />
<strong>Das aktuelle Schlagwort #@id_mot@ wird gelöscht</strong> und seine Links werden dem Wort #@id_mot_new@ zugeordnet: ',
	'label_confirm_fusion_check' => 'Zusammenführen des Wortes #@id_mot@ mit dem Wort #@id_mot_new@ bestätigen',
	'label_dissocier_objets_mot' => '<b>Entfernen</b> dieses Worts von den Objekten mit dem Wort ',
	'label_fusionner_mot' => 'Mit dem Schlagwort <b>zusammenführen</b> ',
	'label_mot_1_enfant' => 'Abgeleitet:',
	'label_mot_nb_enfants' => 'Abgeleitete:',
	'label_mot_parent' => 'Übergeordnet:',

	// P
	'placeholder_id_mot' => 'oder #ID_MOT',
	'placeholder_select' => 'Auswählen…',

	// R
	'result_associer_nb' => 'wurden diesem Schlagwort zugeordnet',
	'result_associer_ras' => 'Nicht erforderlich: Schlagwort bereits allen diesen Objekten zugeordnet',
	'result_cancel_ok' => 'Der letzte Vorgang wurde widerrufen.',
	'result_dissocier_nb' => 'wurden von diesem Schlagwort gelöst',
	'result_dissocier_ras' => 'Kein Bedarf: Diesem Schlagwort ist keines der Objekte zugeordnet.',
	'result_fusionner_ok' => 'Sie können dieses Schlagwort jetzt löschen. Alle Zuordnungen wurden auf das Wort @mot@ übertragen.',

	// T
	'titre_formulaire_administrer_mot' => 'Schlagwort verwalten'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/mots/lang/adminmots_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/adminmots?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_associer' => 'Zuordnen',
	'bouton_dissocier' => 'Entfernen',
	'bouton_fusionner' => 'Zusammenführen',

	// E
	'erreur_admin_mot_action_inconnue' => 'Was möchsten Sie tun?',
	'erreur_mot_cle_deja' => 'Nicht möglich: Sie befinden sich bei diesem Schlagwort.',
	'erreur_selection_id' => 'Wählen Sie ein Schlagwort oder geben Sie seine ID im Eingabefeld an.',

	// I
	'icone_administrer_mot' => 'Erweitert',

	// L
	'label_associer_objets_mot' => 'Dieses Wort Objekten erneut <b>zuordnen</b>',
	'label_confirm_fusion' => 'Dieser Vorgang kann nicht rückgängig gemacht werden.<br />
<strong>Das aktuelle Schlagwort #@id_mot@ wird gelöscht</strong> und seine Links werden dem Wort #@id_mot_new@ zugeordnet: ',
	'label_confirm_fusion_check' => 'Zusammenführen des Wortes #@id_mot@ mit dem Wort #@id_mot_new@ bestätigen',
	'label_dissocier_objets_mot' => '<b>Entfernen</b> dieses Worts von den Objekten mit dem Wort ',
	'label_fusionner_mot' => 'Mit dem Schlagwort <b>zusammenführen</b> ',
	'label_mot_1_enfant' => 'Abgeleitet:',
	'label_mot_nb_enfants' => 'Abgeleitete:',
	'label_mot_parent' => 'Übergeordnet:',

	// P
	'placeholder_id_mot' => 'oder #ID_MOT',
	'placeholder_select' => 'Auswählen…',

	// R
	'result_associer_nb' => 'wurden diesem Schlagwort zugeordnet',
	'result_associer_ras' => 'Nicht erforderlich: Schlagwort bereits allen diesen Objekten zugeordnet',
	'result_cancel_ok' => 'Der letzte Vorgang wurde widerrufen.',
	'result_dissocier_nb' => 'wurden von diesem Schlagwort gelöst',
	'result_dissocier_ras' => 'Kein Bedarf: Diesem Schlagwort ist keines der Objekte zugeordnet.',
	'result_fusionner_ok' => 'Sie können dieses Schlagwort jetzt löschen. Alle Zuordnungen wurden auf das Wort @mot@ übertragen.',

	// T
	'titre_formulaire_administrer_mot' => 'Schlagwort verwalten',
];
